/*
	Test Applet:
	
	   This extension of the applet class is meant to show how
	   a) layout works on a set of simple components
	   b) how simple event processing works
	
	   On Wednesday, I also provided the layout for a more substantial 
	   program (the 2D treasure hunt). On Friday, an example that includes
	   event processing for the treasure hunt will be available.
	   
	
	   In Monday's class, what was covered varied somewhat between one hour and
	   the next. After Wednesday's class, we arrived at a more common ending point 
	   
	   Wednesday's Important Ideas:
	   
		   Components: 
		     a) we added a TextField Component object
		   	 b) we added a Panel object (not only a Component but also a Container)
		     c) there are loads of other interesting components but
		        we'll get by with just these
		     d) your choice of component impacts event handling; some components
		        require more complicated listeners (event handlers). The components
		        that we've chosen only require the simplest listener.
		   
		   Container Objects:
		     a) a Container object is derived from a Component object (i.e.,inheritence)
		     b) most predefined subclasses of Container involve Swing; Panel (and two others)
		        only use the AWT package. Recall that Applet is derived from Panel.
		     c) Container objects are useful due to polymorphism. A Panel object, when
		        seen as a container, allows us to group together components. That same Panel
		        object, when seen as a component, can be added to some other container
		        object - likely another panel within the applet. The applet itself can
		        be thought of as a Panel (again due to polymorphism).
		   		       
	       Layout (Managers):
	         a) Three different layout managers were discussed: 
	       	     	FlowLayout, BorderLayout, and GridLayout
	   	     b) Every Container object has a layout manager (by default, flow)
             c) Individual panels within the applet can each have distinct
                layout managers
	   
		   Event Handling:
		     a) Most components (beyond a Label) are associated with input events. When
		        you examine the API for a component, you'll discover what type of "listener"
		        is required.
		     b) The predefined classes generate all sorts of events. You want to attach
		        a "listener" to any component used for input. The listener is an interface
		        that lists the methods that will be called when an event of the appropriate
		        type occurs.
		     c) We, as programmers, need to implement the listener interface so that we
		        can describe what needs to be done when the event occurs. Generally, the
		        applet itself will implement the interface
		     d) the ActionListener interface is the simplest interface to implement because
		        an ActionEvent is a high-level event. Only a few components can use this
		        interface (Button and TextField, in particular)
	
	At the end of Wednesday's class, we saw only the simplest sort of implementation
	of the ActionListener interface because we only had a single component (namely, Button b1)
	which had a listener.
	   
*/

import java.awt.*;
import java.awt.event.*;  
	// the event subpackage of the awt must be imported so that 
	// the interface ActionListener is known
import java.applet.Applet;

public class TestApplet extends Applet implements ActionListener
		// note that the class implements the ActionListener interface

{

	static Button b1 = new Button("Press Me");
	// because b1 is referenced within the actionPerformed method,
	// it needs to be a class variable

	public void init() {

		add(b1);
		// This next method says that the operation performed when the button is pressed 
		// appears here
		b1.addActionListener(this);

		Label l1 = new Label("Hi there",Label.RIGHT);
		add(l1);
		
		
		Button b2 = new Button("Press me instead");
		b2.addActionListener(new SillyButtonResponse());
		add(b2);
		Panel text = new Panel();
		Label lt = new Label("Input integer:" );
		text.add (lt);
		TextField t = new TextField(5);
		text.add(t);
		
		add(text);
	}
	
	public void actionPerformed (ActionEvent ae) {
	// This method is needed to implement the ActionListener interface

		System.out.println("In action performed: " + ae);
		if (b1.getLabel().equals("Press Me"))
			b1.setLabel("Pull Me");
		else
			b1.setLabel("Press Me");
	}

	/*
	public void paint(Graphics g) {
		g.setColor(Color.blue);
		g.setFont( new Font("Courier",Font.ITALIC,30) );
		g.drawString("Hello World!", 130, 80);
		g.drawRect(100,100,30,30);
		g.setColor(Color.magenta);
		g.drawOval(150,200,75,150);
	}
	*/
}
